@@ -1,11 +1,5 @@
 ##
-# Copyright 2009-2012 Ghent University
-# Copyright 2009-2012 Stijn De Weirdt
-# Copyright 2010 Dries Verdegem
-# Copyright 2010-2012 Kenneth Hoste
-# Copyright 2011 Pieter De Baets
-# Copyright 2011-2012 Jens Timmerman
-#
+# Copyright 2009-2013 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -30,6 +24,12 @@
 ##
 """
 EasyBuild support for AMD Core Math Library (ACML), implemented as an easyblock
+
+@author: Stijn De Weirdt (Ghent University)
+@author: Dries Verdegem (Ghent University)
+@author: Kenneth Hoste (Ghent University)
+@author: Pieter De Baets (Ghent University)
+@author: Jens Timmerman (Ghent University)
 """
 
 import os
@@ -51,8 +51,12 @@ class EB_ACML(EasyBlock):
 
     def __init__(self, *args, **kwargs):
         """Constructor, adds extra class variables."""
-
         super(EB_ACML, self).__init__(*args, **kwargs)
+        self.basedir = None
+        self.suffix = None
+
+    def configure_step(self):
+        """Determine base directory and suffix for ACML installation."""
 
         vsuff_list = self.cfg['versionsuffix'].split('-')
 
@@ -68,10 +72,6 @@ class EB_ACML(EasyBlock):
         if self.cfg['versionsuffix'].split('-')[-1] == "int64":
             self.suffix = '_int64'
 
-    def configure_step(self):
-        """No configure."""
-        pass
-
     def build_step(self):
         """No build."""
         pass
