@@ -81,7 +81,7 @@ class EB_Boost(EasyBlock):
         else:
             self.log.error("Unknown compiler used, aborting.")
 
-        cmd = "./bootstrap.sh --with-toolset=%s --prefix=%s" % (toolset, self.objdir)
+        cmd = "./bootstrap.sh --with-toolset=%s --prefix=%s %s" % (toolset, self.objdir, self.cfg['configopts'])
         run_cmd(cmd, log_all=True, simple=True)
 
         if self.cfg['boost_mpi']:
@@ -145,12 +145,14 @@ class EB_Boost(EasyBlock):
     def sanity_check_step(self):
         """Custom sanity check for Boost."""
 
-        mpifs = []
+        fs = []
         if self.cfg['boost_mpi']:
-            mpifs = ['lib/libboost_mpi.so']
+            fs.append('lib/libboost_mpi.so')
+        if get_software_root('Python'):
+            fs.append('lib/libboost_python.so')
 
         custom_paths = {
-                        'files': mpifs + ['lib/libboost_%s.so' % x for x in ['python', 'system']],
+                        'files': ['lib/libboost_system.so'] + fs,
                        'dirs':['include/boost']
                        }
 
