@@ -41,6 +41,7 @@ import easybuild.tools.environment as env
 from easybuild.easyblocks.generic.intelbase import IntelBase
 from easybuild.framework.easyconfig import CUSTOM
 from easybuild.tools.filetools import rmtree2, run_cmd
+from easybuild.tools.module_generator import det_full_module_name
 from easybuild.tools.modules import Modules, get_software_root
 
 
@@ -116,6 +117,9 @@ class EB_imkl(IntelBase):
         The mkl directory structure has thoroughly changed as from version 10.3.
         Hence post processing is quite different in both situations
         """
+        # reload the dependencies
+        self.load_dependency_modules()
+
         if LooseVersion(self.version) >= LooseVersion('10.3'):
             # Add convenient wrapper libs
             # - form imkl 10.3
@@ -143,10 +147,6 @@ class EB_imkl(IntelBase):
                         self.log.exception("Can't write file %s" % (dest))
 
             # build the mkl interfaces (pic and no-pic)
-            # load the dependencies
-            m = Modules()
-            m.add_module(self.cfg.dependencies())
-            m.load()
 
             if not self.cfg['interfaces']:
                 return
@@ -277,11 +277,6 @@ class EB_imkl(IntelBase):
                     except:
                         self.log.exception("Can't write file %s" % (dest))
 
-            # load the dependencies
-            m = Modules()
-            m.add_module(self.cfg.dependencies())
-            m.load()
-
             if not self.cfg['interfaces']:
                 return
 
